@@ -26,10 +26,12 @@ Puppet::Type.newtype(:postgresql_psql) do
   end
 
   newparam(:unless) do
-    desc 'An optional SQL command to execute prior to the main :command; ' \
-         'this is generally intended to be used for idempotency, to check ' \
-         'for the existence of an object in the database to determine whether ' \
-         'or not the main SQL command needs to be executed at all.'
+    desc <<-DOC
+         An optional SQL command to execute prior to the main :command;
+         this is generally intended to be used for idempotency, to check
+         for the existence of an object in the database to determine whether
+         or not the main SQL command needs to be executed at all.'
+    DOC
 
     # Return true if a matching row is found
     def matches(value)
@@ -45,10 +47,12 @@ Puppet::Type.newtype(:postgresql_psql) do
   end
 
   newparam(:onlyif) do
-    desc 'An optional SQL command to execute prior to the main :command; ' \
-         'this is generally intended to be used for idempotency, to check ' \
-         'for the existence of an object in the database to determine whether ' \
-         'or not the main SQL command needs to be executed at all.'
+    desc <<-DOC
+         An optional SQL command to execute prior to the main :command;
+         this is generally intended to be used for idempotency, to check
+         for the existence of an object in the database to determine whether
+         or not the main SQL command needs to be executed at all.
+    DOC
 
     # Return true if a matching row is found
     def matches(value)
@@ -120,6 +124,8 @@ Puppet::Type.newtype(:postgresql_psql) do
     newvalues(:true, :false)
   end
 
+  autorequire(:class) { ['Postgresql::Server::Service'] }
+
   def should_run_sql(refreshing = false)
     onlyif_param = @parameters[:onlyif]
     unless_param = @parameters[:unless]
