@@ -1,10 +1,11 @@
 Puppet::Type.newtype(:postgresql_replication_slot) do
-  @doc = "Manages Postgresql replication slots.
+  @doc = <<-EOS
+@summary Manages Postgresql replication slots.
 
 This type allows to create and destroy replication slots
 to register warm standby replication on a Postgresql
 master server.
-"
+EOS
 
   ensurable
 
